@@ -131,10 +131,6 @@ class Instance(object):
         return data
 
 
-def everyInstance(instance: Instance):
-    return True
-
-
 def onlyPositiveInstances(instance: Instance):
     return instance.prediction == 1
 
