@@ -1,7 +1,9 @@
 import os
 import re
+import json
 import logging
 import boto3
+import requests
 
 from importlib import import_module
 
@@ -153,6 +155,53 @@ class EmailNotification(RedisModule):
             return None
 
 
+class SocketIO(object):
+    def __init__(
+        self,
+        configuration_directory: str,
+        socketio_url: str,
+        event: str = 'dispatch',
+        **kwargs
+    ):
+        self.configuration_directory = configuration_directory
+        self.socketio_url = socketio_url
+        self.event = event
+
+    def run(self, instance: Instance, **kwargs):
+        pipeline_id = os.path.basename(self.configuration_directory)
+        payload = {
+            "message": "pipeline-new-instance",
+            "data": instance.__dict__,
+            "pipeline_id": pipeline_id,
+        }
+
+        self.emit(self.event, payload, pipeline_id)
+
+        return None
+
+    def emit(self, event: str, payload=None, namespace=None):
+        if not self.socketio_url:
+            return
+
+        logging.info(
+            f"Sending socket io notification to server {self.socketio_url}. Namespace {namespace}"
+        )
+
+        payload["event"] = event
+
+        if namespace:
+            payload["namespace"] = namespace
+
+        try:
+            requests.post(
+                url=self.socketio_url,
+                data=json.dumps(payload),
+                headers={"Content-type": "application/json"},
+            )
+        except Exception:
+            logging.exception("There was an error sending the socket io notification")
+
+
 class AwsSesEmailNotification(object):
     def __init__(
         self, aws_access_key: str, aws_secret_key: str, aws_region_name: str, **kwargs
