@@ -2,6 +2,8 @@ import boto3
 import uuid
 import logging
 import os
+
+from importlib import import_module
 from pathlib import Path
 
 from alira.instance import Instance
@@ -24,7 +26,7 @@ class S3(RedisModule):
         aws_secret_key: str,
         aws_region_name: str,
         redis_server: str = None,
-        filtering_fn: callable = None,
+        filtering: str = None,
         **kwargs,
     ):
         super().__init__(
@@ -38,7 +40,7 @@ class S3(RedisModule):
         self.aws_secret_key = aws_secret_key
         self.aws_region_name = aws_region_name
 
-        self.filtering_fn = filtering_fn
+        self.filtering = self._load_function(filtering)
         self.aws_s3_bucket = aws_s3_bucket
         self.aws_s3_key_prefix = aws_s3_key_prefix
 
@@ -48,7 +50,7 @@ class S3(RedisModule):
         self.aws_s3_public = aws_s3_public
 
     def run(self, instance: Instance, **kwargs):
-        if self.filtering_fn and not self.filtering_fn(instance):
+        if self.filtering and not self.filtering(instance):
             logging.info(
                 f"The instance didn't pass the filtering criteria. Instance: {instance}"
             )
@@ -159,3 +161,17 @@ class S3(RedisModule):
             logging.exception(e)
 
         return None
+
+    def _load_function(self, function_name: str):
+        if function_name is None:
+            return None
+
+        try:
+            module_path, _, fn_name = function_name.rpartition(".")
+            function = getattr(import_module(module_path), fn_name)
+            logging.info(f"Loaded function {function_name}")
+
+            return function
+        except Exception as e:
+            logging.exception(f"Unable to load function {function_name}", e)
+            return None
\ No newline at end of file
