@@ -2,6 +2,8 @@ import os
 import logging
 import yaml
 import json
+import sys
+import importlib.util
 
 from time import time
 from uuid import uuid4
@@ -33,6 +35,7 @@ from alira.instance import Instance
 
 
 PIPELINE_FILENAME = "pipeline.yml"
+PIPELINE_PYTHON_FILENAME = "pipeline.py"
 
 
 class Pipeline(object):
@@ -164,6 +167,8 @@ class Pipeline(object):
                 "the configuration."
             )
 
+        self._load_pipeline_python_file()
+
         self.modules = []
         arguments = {
             "model_identifier": self.model_identifier,
@@ -184,36 +189,31 @@ class Pipeline(object):
             "aws_region_name", self.aws_region_name
         )
 
-        try:
-            for module_configuration in pipeline:
+        for module_configuration in pipeline:
+            try:
                 module_path, _, module_name = module_configuration["module"].rpartition(
                     "."
                 )
                 module = getattr(import_module(module_path), module_name)
                 logging.info(f"Loaded module {module_path}.{module_name}")
+            except ModuleNotFoundError as e:
+                raise RuntimeError(
+                    f"Unable to load module {module_path}.{module_name}"
+                ) from e
 
-                for argument_id, argument in module_configuration.items():
-                    if argument_id == "module":
-                        continue
+            for argument_id, argument in module_configuration.items():
+                if argument_id == "module":
+                    continue
+                
+                arguments[argument_id] = argument
 
-                    if argument_id.endswith("_fn"):
-                        module_path, _, fn_name = argument.rpartition(".")
-                        function = getattr(import_module(module_path), fn_name)
-                        arguments[argument_id] = function
-                        continue
+            arguments["redis_server"] = self.redis_server
+            arguments["aws_access_key"] = self.aws_access_key
+            arguments["aws_secret_key"] = self.aws_secret_key
+            arguments["aws_region_name"] = self.aws_region_name
 
-                    arguments[argument_id] = argument
-
-                arguments["redis_server"] = self.redis_server
-                arguments["aws_access_key"] = self.aws_access_key
-                arguments["aws_secret_key"] = self.aws_secret_key
-                arguments["aws_region_name"] = self.aws_region_name
-
-                arguments.update(self.kwargs)
-                self.modules.append(module(**arguments))
-
-        except ModuleNotFoundError as e:
-            raise RuntimeError(f"Unable to load module {module_path}.{module_name}")
+            arguments.update(self.kwargs)
+            self.modules.append(module(**arguments))
 
     def _initialize_metadata_store(self, store_configuration: dict):
         connection_config = ConnectionConfig()
@@ -266,6 +266,27 @@ class Pipeline(object):
 
         return pipeline_id
 
+    def _load_pipeline_python_file(self):
+        python_filename = os.path.join(
+            self.configuration_directory, PIPELINE_PYTHON_FILENAME
+        )
+        if os.path.isfile(python_filename):
+            module_name = f"{self.model_identifier}.pipeline"
+
+            try:
+                spec = importlib.util.spec_from_file_location(
+                    module_name, python_filename
+                )
+                module = importlib.util.module_from_spec(spec)
+                sys.modules[module_name] = module
+                spec.loader.exec_module(module)
+
+                logging.info(f"Loaded {python_filename} as module {module_name}")
+            except Exception as e:
+                logging.exception(
+                    f"There was an error loading {python_filename} as module {module_name}"
+                )
+
     def _create_pipeline_execution_context(self):
         try:
             _log_message = (
